import { select, symbolsFill, symbol } from 'd3';

const data = [0, 1, 2, 3, 4];
const width = 200;
const height = 500;

// X Channel
const xPosition = (selection, { data, height }) => {
  selection
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('cx', (d) => d * 25 + 40)
    .attr('cy', height / 6)
    .attr('r', (d) => 10);
};

// Y Channel
const yPosition = (selection, { data, width, height }) => {
  selection
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('cx', width / 6)
    .attr('cy', (d) => d * 25 + 40)
    .attr('r', 10);
};

// Size Channel
const size = (selection, { height }) => {
  selection
    .selectAll('circle')
    .data(data)
    .join('circle')
    .attr('cx', (d) => d * 60 - 60)
    .attr('cy', height / 2)
    .attr('r', (d) => Math.sqrt(d * 100) + 10);
};

// Length Channel
const length = (selection, { height }) => {
  const barHeight = (d) => d * 30 + 20;
  selection
    .selectAll('rect')
    .data(data)
    .join('rect')
    .attr('x', (d) => d * 40)
    .attr('y', (d) => height / 3 - barHeight(d))
    .attr('width', 30)
    .attr('height', barHeight);
};

// Shape Channel
const shape = (selection, { height }) => {
  const symbolGenerator = symbol();

  selection
    .selectAll('path')
    .data(data)
    .join('path')
    .attr('d', (d, i) => symbolGenerator.type(symbolsFill[i]).size(3000)());
};

export const viz = (container) => {
  const svg = select(container)
    .selectAll('svg')
    .data([xPosition, yPosition, length, size, shape])
    .join('svg')
    .attr('width', width)
    .attr('height', height)
    .each(function (d) {
      d(select(this), { data, width, height });
    });
};
